propagation - Optical Propagators
=================================

.. currentmodule:: hcipy.propagation

.. automodapi:: hcipy.propagation
    :no-inheritance-diagram:
    :include-all-objects:
    :no-heading: